@@ -6,7 +6,6 @@ use headers::Header;
 use http::header::{HeaderName, HeaderValue};
 use lazy_static::lazy_static;
 use regex::Regex;
-use url;
 
 use crate::fs::DavMetaData;
 
@@ -215,7 +214,7 @@ impl Header for Timeout {
             };
             v.push(w);
         }
-        return Ok(Timeout(v));
+        Ok(Timeout(v))
     }
 
     fn encode<E>(&self, values: &mut E)
@@ -229,9 +228,9 @@ impl Header for Timeout {
                 value.push_str(", ");
             }
             first = false;
-            match s {
-                &DavTimeout::Seconds(n) => value.push_str(&format!("Second-{}", n)),
-                &DavTimeout::Infinite => value.push_str("Infinite"),
+            match *s {
+                DavTimeout::Seconds(n) => value.push_str(&format!("Second-{}", n)),
+                DavTimeout::Infinite => value.push_str("Infinite"),
             }
         }
         values.extend(std::iter::once(HeaderValue::from_str(&value).unwrap()));
@@ -251,7 +250,7 @@ impl Header for Destination {
         I: Iterator<Item = &'i HeaderValue>,
     {
         let s = one(values)?.to_str().map_err(map_invalid)?;
-        if s.starts_with("/") {
+        if s.starts_with('/') {
             return Ok(Destination(s.to_string()));
         }
         if let Some(caps) = RE_URL.captures(s) {
@@ -312,13 +311,13 @@ impl ETag {
     #[allow(dead_code)]
     pub fn new(weak: bool, t: impl Into<String>) -> Result<ETag, headers::Error> {
         let t = t.into();
-        if t.contains("\"") {
+        if t.contains('\"') {
             Err(invalid())
         } else {
             let w = if weak { "W/" } else { "" };
             Ok(ETag {
                 tag: format!("{}\"{}\"", w, t),
-                weak: weak,
+                weak,
             })
         }
     }
@@ -341,15 +340,15 @@ impl FromStr for ETag {
     type Err = headers::Error;
 
     fn from_str(t: &str) -> Result<Self, Self::Err> {
-        let (weak, s) = if t.starts_with("W/") {
-            (true, &t[2..])
+        let (weak, s) = if let Some(t) = t.strip_prefix("W/") {
+            (true, t)
         } else {
             (false, t)
         };
-        if s.starts_with("\"") && s.ends_with("\"") && !s[1..s.len() - 1].contains("\"") {
+        if s.starts_with('\"') && s.ends_with('\"') && !s[1..s.len() - 1].contains('\"') {
             Ok(ETag {
                 tag: t.to_owned(),
-                weak: weak,
+                weak,
             })
         } else {
             Err(invalid())
@@ -433,9 +432,9 @@ impl Header for IfRange {
     where
         E: Extend<HeaderValue>,
     {
-        match self {
-            &IfRange::Date(ref d) => d.encode(values),
-            &IfRange::ETag(ref t) => t.encode(values),
+        match *self {
+            IfRange::Date(ref d) => d.encode(values),
+            IfRange::ETag(ref t) => t.encode(values),
         }
     }
 }
@@ -485,9 +484,9 @@ fn encode_etaglist<E>(m: &ETagList, values: &mut E)
 where
     E: Extend<HeaderValue>,
 {
-    let value = match m {
-        &ETagList::Star => "*".to_string(),
-        &ETagList::Tags(ref t) => t
+    let value = match *m {
+        ETagList::Star => "*".to_string(),
+        ETagList::Tags(ref t) => t
             .iter()
             .map(|t| t.tag.as_str())
             .collect::<Vec<&str>>()
@@ -562,38 +561,38 @@ impl Header for XUpdateRange {
         }
         s = &s[6..];
 
-        let nums = s.split("-").collect::<Vec<&str>>();
+        let nums = s.split('-').collect::<Vec<&str>>();
         if nums.len() != 2 {
             return Err(invalid());
         }
-        if nums[0] != "" && nums[1] != "" {
+        if !nums[0].is_empty() && !nums[1].is_empty() {
             return Ok(XUpdateRange::FromTo(
                 (nums[0]).parse::<u64>().map_err(map_invalid)?,
                 (nums[1]).parse::<u64>().map_err(map_invalid)?,
             ));
         }
-        if nums[0] != "" {
+        if !nums[0].is_empty() {
             return Ok(XUpdateRange::AllFrom(
                 (nums[0]).parse::<u64>().map_err(map_invalid)?,
             ));
         }
-        if nums[1] != "" {
+        if !nums[1].is_empty() {
             return Ok(XUpdateRange::Last(
                 (nums[1]).parse::<u64>().map_err(map_invalid)?,
             ));
         }
-        return Err(invalid());
+        Err(invalid())
     }
 
     fn encode<E>(&self, values: &mut E)
     where
         E: Extend<HeaderValue>,
     {
-        let value = match self {
-            &XUpdateRange::Append => "append".to_string(),
-            &XUpdateRange::FromTo(b, e) => format!("{}-{}", b, e),
-            &XUpdateRange::AllFrom(b) => format!("{}-", b),
-            &XUpdateRange::Last(e) => format!("-{}", e),
+        let value = match *self {
+            XUpdateRange::Append => "append".to_string(),
+            XUpdateRange::FromTo(b, e) => format!("{}-{}", b, e),
+            XUpdateRange::AllFrom(b) => format!("{}-", b),
+            XUpdateRange::Last(e) => format!("-{}", e),
         };
         values.extend(std::iter::once(HeaderValue::from_str(&value).unwrap()));
     }
@@ -664,7 +663,7 @@ fn is_special(c: u8) -> bool {
     b"<>()[]".iter().any(|&x| x == c)
 }
 
-fn trim_left<'a>(mut out: &'a [u8]) -> &'a [u8] {
+fn trim_left(mut out: &'_ [u8]) -> &'_ [u8] {
     while !out.is_empty() && is_whitespace(out[0]) {
         out = &out[1..];
     }
@@ -701,7 +700,7 @@ fn scan_word(buf: &[u8]) -> Result<(&[u8], &[u8]), headers::Error> {
 }
 
 // get next token.
-fn get_token<'a>(buf: &'a [u8]) -> Result<(IfToken, &'a [u8]), headers::Error> {
+fn get_token(buf: &'_ [u8]) -> Result<(IfToken, &'_ [u8]), headers::Error> {
     let buf = trim_left(buf);
     if buf.is_empty() {
         return Ok((IfToken::End, buf));
@@ -760,7 +759,7 @@ impl Header for If {
                         IfState::RTag
                     }
                     IfToken::End => {
-                        if if_lists.0.len() > 0 {
+                        if !if_lists.0.is_empty() {
                             break;
                         }
                         IfState::Bad
@@ -784,7 +783,7 @@ impl Header for If {
                         IfToken::Pointy(stok) | IfToken::Word(stok) => {
                             // as we don't have an URI parser, just
                             // check if there's at least one ':' in there.
-                            if !stok.contains(":") {
+                            if !stok.contains(':') {
                                 IfState::Bad
                             } else {
                                 cur_list.add(not, IfItem::StateToken(stok));
