@@ -8,11 +8,13 @@ use std::any::Any;
 use std::collections::VecDeque;
 use std::future::Future;
 use std::io::{self, ErrorKind, Read, Seek, SeekFrom, Write};
-use std::os::unix::ffi::OsStrExt;
-use std::os::unix::fs::DirBuilderExt;
-use std::os::unix::fs::MetadataExt;
-use std::os::unix::fs::OpenOptionsExt;
-use std::os::unix::fs::PermissionsExt;
+#[cfg(unix)]
+use std::os::unix::{
+    ffi::OsStrExt,
+    fs::{DirBuilderExt, MetadataExt, OpenOptionsExt, PermissionsExt},
+};
+#[cfg(target_os = "windows")]
+use std::os::windows::prelude::*;
 use std::path::{Path, PathBuf};
 use std::pin::Pin;
 use std::sync::atomic::{AtomicU32, Ordering};
@@ -91,6 +93,7 @@ pub struct LocalFs {
 // inner struct.
 pub(crate) struct LocalFsInner {
     pub basedir: PathBuf,
+    #[allow(dead_code)]
     pub public: bool,
     pub case_insensitive: bool,
     pub macos: bool,
@@ -140,9 +143,9 @@ impl LocalFs {
     ) -> Box<LocalFs> {
         let inner = LocalFsInner {
             basedir: base.as_ref().to_path_buf(),
-            public: public,
-            macos: macos,
-            case_insensitive: case_insensitive,
+            public,
+            macos,
+            case_insensitive,
             is_file: false,
             fs_access_guard: None,
         };
@@ -160,7 +163,7 @@ impl LocalFs {
     pub fn new_file<P: AsRef<Path>>(file: P, public: bool) -> Box<LocalFs> {
         let inner = LocalFsInner {
             basedir: file.as_ref().to_path_buf(),
-            public: public,
+            public,
             macos: false,
             case_insensitive: false,
             is_file: true,
@@ -184,11 +187,11 @@ impl LocalFs {
     ) -> Box<LocalFs> {
         let inner = LocalFsInner {
             basedir: base.as_ref().to_path_buf(),
-            public: public,
-            macos: macos,
-            case_insensitive: case_insensitive,
+            public,
+            macos,
+            case_insensitive,
             is_file: false,
-            fs_access_guard: fs_access_guard,
+            fs_access_guard,
         };
         Box::new({
             LocalFs {
@@ -207,7 +210,7 @@ impl LocalFs {
 
     fn fspath(&self, path: &DavPath) -> PathBuf {
         if self.inner.case_insensitive {
-            crate::localfs_windows::resolve(&self.inner.basedir, &path)
+            crate::localfs_windows::resolve(&self.inner.basedir, path)
         } else {
             let mut pathbuf = self.inner.basedir.clone();
             if !self.inner.is_file {
@@ -308,9 +311,11 @@ impl DavFileSystem for LocalFs {
             if self.is_forbidden(path) {
                 return Err(FsError::Forbidden);
             }
+            #[cfg(unix)]
             let mode = if self.inner.public { 0o644 } else { 0o600 };
             let path = self.fspath(path);
             self.blocking(move || {
+                #[cfg(unix)]
                 let res = std::fs::OpenOptions::new()
                     .read(options.read)
                     .write(options.write)
@@ -320,6 +325,15 @@ impl DavFileSystem for LocalFs {
                     .create_new(options.create_new)
                     .mode(mode)
                     .open(path);
+                #[cfg(windows)]
+                let res = std::fs::OpenOptions::new()
+                    .read(options.read)
+                    .write(options.write)
+                    .append(options.append)
+                    .truncate(options.truncate)
+                    .create(options.create)
+                    .create_new(options.create_new)
+                    .open(path);
                 match res {
                     Ok(file) => Ok(Box::new(LocalFsFile(Some(file))) as Box<dyn DavFile>),
                     Err(e) => Err(e.into()),
@@ -336,13 +350,23 @@ impl DavFileSystem for LocalFs {
             if self.is_forbidden(path) {
                 return Err(FsError::Forbidden);
             }
+            #[cfg(unix)]
             let mode = if self.inner.public { 0o755 } else { 0o700 };
             let path = self.fspath(path);
             self.blocking(move || {
-                std::fs::DirBuilder::new()
-                    .mode(mode)
-                    .create(path)
-                    .map_err(|e| e.into())
+                #[cfg(unix)]
+                {
+                    std::fs::DirBuilder::new()
+                        .mode(mode)
+                        .create(path)
+                        .map_err(|e| e.into())
+                }
+                #[cfg(windows)]
+                {
+                    std::fs::DirBuilder::new()
+                        .create(path)
+                        .map_err(|e| e.into())
+                }
             })
             .await
         }
@@ -474,10 +498,7 @@ fn read_batch(
                     ReadDirMeta::DataSymlink => Meta::Data(entry.metadata()),
                     ReadDirMeta::None => Meta::Fs(fs.clone()),
                 };
-                let d = LocalFsDirEntry {
-                    meta: meta,
-                    entry: entry,
-                };
+                let d = LocalFsDirEntry { meta, entry };
                 buffer.push_back(Ok(d))
             }
             Some(Err(e)) => {
@@ -517,7 +538,7 @@ impl<'a> Stream for LocalFsReadDir {
         let this = Pin::into_inner(self);
 
         // If the buffer is empty, fill it.
-        if this.buffer.len() == 0 {
+        if this.buffer.is_empty() {
             // If we have no pending future, create one.
             if this.fut.is_none() {
                 if this.iterator.is_none() {
@@ -533,11 +554,11 @@ impl<'a> Stream for LocalFsReadDir {
                 Poll::Ready(batch) => {
                     this.fut.take();
                     if let Some(ref mut nb) = this.dir_cache {
-                        for e in &batch.buffer {
+                        batch.buffer.iter().for_each(|e| {
                             if let Ok(ref e) = e {
                                 nb.add(e.entry.file_name());
                             }
-                        }
+                        });
                     }
                     this.buffer = batch.buffer;
                     this.iterator = batch.iterator;
@@ -595,7 +616,7 @@ impl LocalFsDirEntry {
 }
 
 impl DavDirEntry for LocalFsDirEntry {
-    fn metadata<'a>(&'a self) -> FsFuture<Box<dyn DavMetaData>> {
+    fn metadata(&self) -> FsFuture<Box<dyn DavMetaData>> {
         match self.meta {
             Meta::Data(ref meta) => {
                 let m = match meta {
@@ -615,25 +636,31 @@ impl DavDirEntry for LocalFsDirEntry {
         }
     }
 
+    #[cfg(unix)]
     fn name(&self) -> Vec<u8> {
         self.entry.file_name().as_bytes().to_vec()
     }
 
-    fn is_dir<'a>(&'a self) -> FsFuture<bool> {
+    #[cfg(windows)]
+    fn name(&self) -> Vec<u8> {
+        self.entry.file_name().to_str().unwrap().as_bytes().to_vec()
+    }
+
+    fn is_dir(&self) -> FsFuture<bool> {
         Box::pin(self.is_a(Is::Dir))
     }
 
-    fn is_file<'a>(&'a self) -> FsFuture<bool> {
+    fn is_file(&self) -> FsFuture<bool> {
         Box::pin(self.is_a(Is::File))
     }
 
-    fn is_symlink<'a>(&'a self) -> FsFuture<bool> {
+    fn is_symlink(&self) -> FsFuture<bool> {
         Box::pin(self.is_a(Is::Symlink))
     }
 }
 
 impl DavFile for LocalFsFile {
-    fn metadata<'a>(&'a mut self) -> FsFuture<Box<dyn DavMetaData>> {
+    fn metadata(&mut self) -> FsFuture<Box<dyn DavMetaData>> {
         async move {
             let file = self.0.take().unwrap();
             let (meta, file) = blocking(move || (file.metadata(), file)).await;
@@ -643,7 +670,7 @@ impl DavFile for LocalFsFile {
         .boxed()
     }
 
-    fn write_bytes<'a>(&'a mut self, buf: Bytes) -> FsFuture<()> {
+    fn write_bytes(&mut self, buf: Bytes) -> FsFuture<()> {
         async move {
             let mut file = self.0.take().unwrap();
             let (res, file) = blocking(move || (file.write_all(&buf), file)).await;
@@ -653,7 +680,7 @@ impl DavFile for LocalFsFile {
         .boxed()
     }
 
-    fn write_buf<'a>(&'a mut self, mut buf: Box<dyn Buf + Send>) -> FsFuture<()> {
+    fn write_buf(&mut self, mut buf: Box<dyn Buf + Send>) -> FsFuture<()> {
         async move {
             let mut file = self.0.take().unwrap();
             let (res, file) = blocking(move || {
@@ -673,7 +700,7 @@ impl DavFile for LocalFsFile {
         .boxed()
     }
 
-    fn read_bytes<'a>(&'a mut self, count: usize) -> FsFuture<Bytes> {
+    fn read_bytes(&mut self, count: usize) -> FsFuture<Bytes> {
         async move {
             let mut file = self.0.take().unwrap();
             let (res, file) = blocking(move || {
@@ -694,7 +721,7 @@ impl DavFile for LocalFsFile {
         .boxed()
     }
 
-    fn seek<'a>(&'a mut self, pos: SeekFrom) -> FsFuture<u64> {
+    fn seek(&mut self, pos: SeekFrom) -> FsFuture<u64> {
         async move {
             let mut file = self.0.take().unwrap();
             let (res, file) = blocking(move || (file.seek(pos), file)).await;
@@ -704,7 +731,7 @@ impl DavFile for LocalFsFile {
         .boxed()
     }
 
-    fn flush<'a>(&'a mut self) -> FsFuture<()> {
+    fn flush(&mut self) -> FsFuture<()> {
         async move {
             let mut file = self.0.take().unwrap();
             let (res, file) = blocking(move || (file.flush(), file)).await;
@@ -729,10 +756,16 @@ impl DavMetaData for LocalFsMetaData {
         self.0.accessed().map_err(|e| e.into())
     }
 
+    #[cfg(unix)]
     fn status_changed(&self) -> FsResult<SystemTime> {
         Ok(UNIX_EPOCH + Duration::new(self.0.ctime() as u64, 0))
     }
 
+    #[cfg(windows)]
+    fn status_changed(&self) -> FsResult<SystemTime> {
+        Ok(UNIX_EPOCH + Duration::from_nanos(self.0.creation_time() - 116444736000000000))
+    }
+
     fn is_dir(&self) -> bool {
         self.0.is_dir()
     }
@@ -742,6 +775,8 @@ impl DavMetaData for LocalFsMetaData {
     fn is_symlink(&self) -> bool {
         self.0.file_type().is_symlink()
     }
+
+    #[cfg(unix)]
     fn executable(&self) -> FsResult<bool> {
         if self.0.is_file() {
             return Ok((self.0.permissions().mode() & 0o100) > 0);
@@ -749,7 +784,14 @@ impl DavMetaData for LocalFsMetaData {
         Err(FsError::NotImplemented)
     }
 
+    #[cfg(windows)]
+    fn executable(&self) -> FsResult<bool> {
+        // FIXME: implement
+        Err(FsError::NotImplemented)
+    }
+
     // same as the default apache etag.
+    #[cfg(unix)]
     fn etag(&self) -> Option<String> {
         let modified = self.0.modified().ok()?;
         let t = modified.duration_since(UNIX_EPOCH).ok()?;
@@ -760,6 +802,19 @@ impl DavMetaData for LocalFsMetaData {
             Some(format!("{:x}-{:x}", self.0.ino(), t))
         }
     }
+
+    // same as the default apache etag.
+    #[cfg(windows)]
+    fn etag(&self) -> Option<String> {
+        let modified = self.0.modified().ok()?;
+        let t = modified.duration_since(UNIX_EPOCH).ok()?;
+        let t = t.as_secs() * 1000000 + t.subsec_nanos() as u64 / 1000;
+        if self.is_file() {
+            Some(format!("{:x}-{:x}", self.0.len(), t))
+        } else {
+            Some(format!("{:x}", t))
+        }
+    }
 }
 
 impl From<&io::Error> for FsError {
@@ -767,7 +822,10 @@ impl From<&io::Error> for FsError {
         if let Some(errno) = e.raw_os_error() {
             // specific errors.
             match errno {
+                #[cfg(unix)]
                 libc::EMLINK | libc::ENOSPC | libc::EDQUOT => return FsError::InsufficientStorage,
+                #[cfg(windows)]
+                libc::EMLINK | libc::ENOSPC => return FsError::InsufficientStorage,
                 libc::EFBIG => return FsError::TooLarge,
                 libc::EACCES | libc::EPERM => return FsError::Forbidden,
                 libc::ENOTEMPTY | libc::EEXIST => return FsError::Exists,
