@@ -109,7 +109,7 @@ impl MemFs {
         }
         Ok(Box::new(MemFsFile {
             tree: self.tree.clone(),
-            node_id: node_id,
+            node_id,
             pos: 0,
             append: options.append,
         }))
@@ -266,8 +266,7 @@ impl DavFileSystem for MemFs {
 
             let mut res = Vec::new();
 
-            let patch = patch.drain(..).collect::<Vec<_>>();
-            for (set, p) in patch.into_iter() {
+            for (set, p) in patch.drain(..) {
                 let prop = cloneprop(&p);
                 let status = if set {
                     props.insert(propkey(&p.namespace, &p.name), p);
@@ -293,7 +292,7 @@ impl DavFileSystem for MemFs {
             let node_id = tree.lookup(path.as_bytes())?;
             let node = tree.get_node(node_id)?;
             let mut res = Vec::new();
-            for (_, p) in node.get_props() {
+            for p in node.get_props().values() {
                 res.push(if do_content { p.clone() } else { cloneprop(p) });
             }
             Ok(res)
@@ -310,7 +309,7 @@ impl DavFileSystem for MemFs {
                 .get_props()
                 .get(&propkey(&prop.namespace, &prop.name))
                 .ok_or(FsError::NotFound)?;
-            Ok(p.xml.clone().ok_or(FsError::NotFound)?)
+            p.xml.clone().ok_or(FsError::NotFound)
         }
         .boxed()
     }
@@ -332,7 +331,7 @@ fn cloneprop(p: &DavProp) -> DavProp {
 }
 
 impl DavDirEntry for MemFsDirEntry {
-    fn metadata<'a>(&'a self) -> FsFuture<Box<dyn DavMetaData>> {
+    fn metadata(&self) -> FsFuture<Box<dyn DavMetaData>> {
         let meta = (*self).clone();
         Box::pin(future::ok(Box::new(meta) as Box<dyn DavMetaData>))
     }
@@ -343,7 +342,7 @@ impl DavDirEntry for MemFsDirEntry {
 }
 
 impl DavFile for MemFsFile {
-    fn metadata<'a>(&'a mut self) -> FsFuture<Box<dyn DavMetaData>> {
+    fn metadata(&mut self) -> FsFuture<Box<dyn DavMetaData>> {
         async move {
             let tree = &*self.tree.lock().unwrap();
             let node = tree.get_node(self.node_id)?;
@@ -353,7 +352,7 @@ impl DavFile for MemFsFile {
         .boxed()
     }
 
-    fn read_bytes<'a>(&'a mut self, count: usize) -> FsFuture<Bytes> {
+    fn read_bytes(&mut self, count: usize) -> FsFuture<Bytes> {
         async move {
             let tree = &*self.tree.lock().unwrap();
             let node = tree.get_node(self.node_id)?;
@@ -374,7 +373,7 @@ impl DavFile for MemFsFile {
         .boxed()
     }
 
-    fn write_bytes<'a>(&'a mut self, buf: Bytes) -> FsFuture<()> {
+    fn write_bytes(&mut self, buf: Bytes) -> FsFuture<()> {
         async move {
             let tree = &mut *self.tree.lock().unwrap();
             let node = tree.get_node_mut(self.node_id)?;
@@ -393,7 +392,7 @@ impl DavFile for MemFsFile {
         .boxed()
     }
 
-    fn write_buf<'a>(&'a mut self, mut buf: Box<dyn Buf + Send>) -> FsFuture<()> {
+    fn write_buf(&mut self, mut buf: Box<dyn Buf + Send>) -> FsFuture<()> {
         async move {
             let tree = &mut *self.tree.lock().unwrap();
             let node = tree.get_node_mut(self.node_id)?;
@@ -417,11 +416,11 @@ impl DavFile for MemFsFile {
         .boxed()
     }
 
-    fn flush<'a>(&'a mut self) -> FsFuture<()> {
+    fn flush(&mut self) -> FsFuture<()> {
         future::ok(()).boxed()
     }
 
-    fn seek<'a>(&'a mut self, pos: SeekFrom) -> FsFuture<u64> {
+    fn seek(&mut self, pos: SeekFrom) -> FsFuture<u64> {
         async move {
             let (start, offset): (u64, i64) = match pos {
                 SeekFrom::Start(npos) => {
@@ -488,58 +487,58 @@ impl MemFsNode {
 
     // helper to create MemFsDirEntry from a node.
     fn as_dirent(&self, name: &[u8]) -> MemFsDirEntry {
-        let (is_dir, size, mtime, crtime) = match self {
-            &MemFsNode::File(ref file) => (false, file.data.len() as u64, file.mtime, file.crtime),
-            &MemFsNode::Dir(ref dir) => (true, 0, dir.mtime, dir.crtime),
+        let (is_dir, size, mtime, crtime) = match *self {
+            MemFsNode::File(ref file) => (false, file.data.len() as u64, file.mtime, file.crtime),
+            MemFsNode::Dir(ref dir) => (true, 0, dir.mtime, dir.crtime),
         };
         MemFsDirEntry {
             name: name.to_vec(),
-            mtime: mtime,
-            crtime: crtime,
-            is_dir: is_dir,
+            mtime,
+            crtime,
+            is_dir,
             size: size as u64,
         }
     }
 
     fn update_mtime(&mut self, tm: std::time::SystemTime) {
-        match self {
-            &mut MemFsNode::Dir(ref mut d) => d.mtime = tm,
-            &mut MemFsNode::File(ref mut f) => f.mtime = tm,
+        match *self {
+            MemFsNode::Dir(ref mut d) => d.mtime = tm,
+            MemFsNode::File(ref mut f) => f.mtime = tm,
         }
     }
 
     fn is_dir(&self) -> bool {
-        match self {
-            &MemFsNode::Dir(_) => true,
-            &MemFsNode::File(_) => false,
+        match *self {
+            MemFsNode::Dir(_) => true,
+            MemFsNode::File(_) => false,
         }
     }
 
     fn as_file(&self) -> FsResult<&MemFsFileNode> {
-        match self {
-            &MemFsNode::File(ref n) => Ok(n),
+        match *self {
+            MemFsNode::File(ref n) => Ok(n),
             _ => Err(FsError::Forbidden),
         }
     }
 
     fn as_file_mut(&mut self) -> FsResult<&mut MemFsFileNode> {
-        match self {
-            &mut MemFsNode::File(ref mut n) => Ok(n),
+        match *self {
+            MemFsNode::File(ref mut n) => Ok(n),
             _ => Err(FsError::Forbidden),
         }
     }
 
     fn get_props(&self) -> &HashMap<String, DavProp> {
-        match self {
-            &MemFsNode::File(ref n) => &n.props,
-            &MemFsNode::Dir(ref d) => &d.props,
+        match *self {
+            MemFsNode::File(ref n) => &n.props,
+            MemFsNode::Dir(ref d) => &d.props,
         }
     }
 
     fn get_props_mut(&mut self) -> &mut HashMap<String, DavProp> {
-        match self {
-            &mut MemFsNode::File(ref mut n) => &mut n.props,
-            &mut MemFsNode::Dir(ref mut d) => &mut d.props,
+        match *self {
+            MemFsNode::File(ref mut n) => &mut n.props,
+            MemFsNode::Dir(ref mut d) => &mut d.props,
         }
     }
 }
@@ -568,13 +567,20 @@ impl TreeExt for Tree {
     }
 
     fn lookup(&self, path: &[u8]) -> FsResult<u64> {
-        self.lookup_segs(path.split(|&c| c == b'/').filter(|s| s.len() > 0).collect())
+        self.lookup_segs(
+            path.split(|&c| c == b'/')
+                .filter(|s| !s.is_empty())
+                .collect(),
+        )
     }
 
     // pop the last segment off the path, do a lookup, then
     // check if the result is a directory.
     fn lookup_parent(&self, path: &[u8]) -> FsResult<u64> {
-        let mut segs: Vec<&[u8]> = path.split(|&c| c == b'/').filter(|s| s.len() > 0).collect();
+        let mut segs: Vec<&[u8]> = path
+            .split(|&c| c == b'/')
+            .filter(|s| !s.is_empty())
+            .collect();
         segs.pop();
         let node_id = self.lookup_segs(segs)?;
         if !self.get_node(node_id)?.is_dir() {
@@ -587,7 +593,7 @@ impl TreeExt for Tree {
 // helper
 fn file_name(path: &[u8]) -> Vec<u8> {
     path.split(|&c| c == b'/')
-        .filter(|s| s.len() > 0)
+        .filter(|s| !s.is_empty())
         .last()
         .unwrap_or(b"")
         .to_vec()
